pub enum NativeEventError {
Lagged(u64),
Closed,
}Expand description
Failure while consuming a native broadcast or status stream.
Variants
Lagged(u64)
The bounded broadcast receiver missed this many messages.
Closed
All senders for the event or status stream were dropped.