pub struct NativeOptions { /* private fields */ }Expand description
Settings for a dedicated native client worker.
Implementations
Sourceimpl NativeOptions
impl NativeOptions
Sourcepub fn heartbeat_interval(self, value: Duration) -> Self
pub fn heartbeat_interval(self, value: Duration) -> Self
Sets the automatic heartbeat interval.
Sourcepub fn heartbeat_timeout(self, value: Duration) -> Self
pub fn heartbeat_timeout(self, value: Duration) -> Self
Sets the automatic heartbeat acknowledgement timeout.
Sourcepub fn connect_timeout(self, value: Duration) -> Self
pub fn connect_timeout(self, value: Duration) -> Self
Sets the maximum duration of a transport connection attempt.
Sourcepub fn request_timeout(self, value: Duration) -> Self
pub fn request_timeout(self, value: Duration) -> Self
Sets join, call, and leave timeouts to one common value.
Sourcepub fn join_timeout(self, value: Duration) -> Self
pub fn join_timeout(self, value: Duration) -> Self
Sets the default join timeout.
Sourcepub fn call_timeout(self, value: Duration) -> Self
pub fn call_timeout(self, value: Duration) -> Self
Sets the default call timeout.
Sourcepub fn leave_timeout(self, value: Duration) -> Self
pub fn leave_timeout(self, value: Duration) -> Self
Sets the default leave timeout.
Sourcepub fn reconnect_delays(
self,
values: impl IntoIterator<Item = Duration>,
) -> Self
pub fn reconnect_delays( self, values: impl IntoIterator<Item = Duration>, ) -> Self
Sets reconnect delays by attempt, retaining the final delay thereafter.
Sourcepub fn rejoin_delays(self, values: impl IntoIterator<Item = Duration>) -> Self
pub fn rejoin_delays(self, values: impl IntoIterator<Item = Duration>) -> Self
Sets rejoin delays by attempt, retaining the final delay thereafter.
Sourcepub fn command_capacity(self, value: usize) -> Self
pub fn command_capacity(self, value: usize) -> Self
Sets the bounded host-to-worker command capacity.
Sourcepub fn push_buffer_capacity(self, value: usize) -> Self
pub fn push_buffer_capacity(self, value: usize) -> Self
Sets how many calls may wait for a connection or join.
Sourcepub fn event_capacity(self, value: usize) -> Self
pub fn event_capacity(self, value: usize) -> Self
Sets each broadcast event channel’s capacity.
Sourcepub fn telemetry(self, hook: NativeTelemetryHook) -> Self
pub fn telemetry(self, hook: NativeTelemetryHook) -> Self
Installs a thread-safe telemetry callback.
Sourcepub fn reconnect_policy(self, policy: NativeReconnectPolicy) -> Self
pub fn reconnect_policy(self, policy: NativeReconnectPolicy) -> Self
Installs a thread-safe reconnect policy.
Sourcepub fn transport(self, options: NativeTransportOptions) -> Self
pub fn transport(self, options: NativeTransportOptions) -> Self
Replaces native WebSocket transport settings.